import { Row, Col, Typography, Space, Tooltip, Statistic, Spin } from 'antd';
import { FileOutlined, HddOutlined, UserOutlined, CheckCircleOutlined, HistoryOutlined } from '@ant-design/icons';
import DashboardCard from '@web/src/components/presentation/dashboard-card';
import { useDashboardContext } from '../DashboardContext';
import { useEffect, useState } from 'react';
const { Title, Text } = Typography;
export default function Board() {
    const { shareCodeAll, shareCodeToday, shareCodeYesterday,
        isShareCodeAllLoading, isShareCodeTodayLoading, isShareCodeYesterdayLoading,
        distinctUploadIPs, isDistinctUploadIPsLoading } = useDashboardContext();
    const [serverUptime, setServerUptime] = useState('');
    useEffect(() => {
        const calculateTimeDifference = () => {
            const now = new Date();
            const targetDate = new Date('2025-04-09T15:00:00');
            const diffMs = now.getTime()- targetDate.getTime();

            // 如果是负数，表示目标日期已过
            if (diffMs < 0) {
                setServerUptime('0天0小时0分钟');
                return;
            }

            // 计算天数、小时数和分钟数
            const days = Math.floor(diffMs / (1000 * 60 * 60 * 24));
            const hours = Math.floor((diffMs % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
            const minutes = Math.floor((diffMs % (1000 * 60 * 60)) / (1000 * 60));

            setServerUptime(`${days}天${hours}小时${minutes}分钟`);
        };

        calculateTimeDifference();
        // 每分钟更新一次
        const timer = setInterval(calculateTimeDifference, 60000);

        return () => clearInterval(timer);
    }, []);
    return <>
        <Title level={3} className="mb-4">仪表盘</Title>
        <Row gutter={[16, 16]}>
            {/* 总文件数卡片 */}
            <Col xs={24} sm={12} md={6}>
                <DashboardCard
                    title={
                        <div className="flex items-center">
                            <FileOutlined style={{ marginRight: 8, fontSize: 16 }} />
                            总文件数
                        </div>
                    }
                    className="h-full"
                >
                    <div className="flex flex-col h-full justify-between py-2">
                        <Statistic value={isShareCodeAllLoading ? 0 : shareCodeAll?.resourceCount} />
                        {
                            isShareCodeTodayLoading || isShareCodeYesterdayLoading
                                ? <Spin />
                                : (<div className="text-gray-500 text-sm mt-2">
                                    昨天: {shareCodeYesterday?.resourceCount} 今天: {shareCodeToday?.resourceCount}
                                </div>)
                        }
                    </div>
                </DashboardCard>
            </Col>

            {/* 存储空间卡片 */}
            <Col xs={24} sm={12} md={6}>
                <DashboardCard
                    title={
                        <div className="flex items-center">
                            <HddOutlined style={{ marginRight: 8, fontSize: 16 }} />
                            已使用的存储空间
                        </div>
                    }
                    className="h-full"
                >
                    <div className="flex flex-col h-full justify-between py-2">
                        <Statistic value={isShareCodeAllLoading ? 0 : `${(shareCodeAll?.totalSize / 1024 / 1024 / 1024).toFixed(2)}GB`} />
                        {
                            isShareCodeTodayLoading || isShareCodeYesterdayLoading
                                ? <Spin />
                                : (<div className="text-gray-500 text-sm mt-2">
                                    昨天: {(shareCodeYesterday?.totalSize / 1024 / 1024).toFixed(2)}MB 今天: {(shareCodeToday?.totalSize / 1024 / 1024).toFixed(2)}MB
                                </div>)
                        }
                    </div>
                </DashboardCard>
            </Col>

            {/* 活跃用户卡片 */}
            <Col xs={24} sm={12} md={6}>
                <DashboardCard
                    title={
                        <div className="flex items-center">
                            <UserOutlined style={{ marginRight: 8, fontSize: 16 }} />
                            全部用户
                        </div>
                    }
                    className="h-full"
                >
                    <div className="flex flex-col h-full justify-between py-2">
                        <Statistic value={isDistinctUploadIPsLoading ? 0 : distinctUploadIPs?.all} />

                        <div className="text-gray-500 text-sm mt-2">
                            上周使用用户: {distinctUploadIPs?.lastWeek} 本周使用用户: {distinctUploadIPs?.thisWeek}
                            {
                                distinctUploadIPs?.lastWeek ? (
                                    distinctUploadIPs?.lastWeek > distinctUploadIPs?.thisWeek ?
                                        <span className="text-red-500">↓{((distinctUploadIPs?.lastWeek - distinctUploadIPs?.thisWeek) / distinctUploadIPs?.lastWeek * 100).toFixed(2)}%</span>
                                        : <span className="text-green-500">↑ {((distinctUploadIPs?.thisWeek - distinctUploadIPs?.lastWeek) / distinctUploadIPs?.lastWeek * 100).toFixed(2)}%</span>
                                ) : null
                            }
                        </div>
                    </div>
                </DashboardCard>
            </Col>

            {/* 系统状态卡片 */}
            <Col xs={24} sm={12} md={6}>
                <DashboardCard
                    title={
                        <div className="flex items-center">
                            <CheckCircleOutlined style={{ marginRight: 8, fontSize: 16, color: "#52c41a" }} />
                            系统状态
                        </div>
                    }
                    className="h-full"
                >
                    <div className="flex flex-col h-full justify-between py-2">
                        <Statistic value="正常" valueStyle={{ color: '#52c41a' }} />
                        <div className="text-gray-500 text-sm mt-2">
                            服务器运行时间: {serverUptime}
                        </div>
                    </div>
                </DashboardCard>
            </Col>
        </Row>
    </>
}