import { useAuth } from "@web/src/providers/auth-provider";
import { Button } from "antd";
import { RolePerms } from "@nice/common";
import { useNavigate } from "react-router-dom";

interface HeaderProps {
  showLoginButton?: boolean;
}

export const Header: React.FC<HeaderProps> = ({ showLoginButton = true }) => {
  const navigate = useNavigate();
  const {isAuthenticated , hasEveryPermissions} = useAuth();
  const isAdmin = hasEveryPermissions(RolePerms.MANAGE_ANY_POST) && isAuthenticated;

  return (
    <div className="w-[1000px] mx-auto flex justify-between items-center pt-3">
      <div className="flex items-center">
        <img src="/logo.svg" className="h-16 w-16" />
        <span className="text-4xl py-4 mx-4 font-bold text-transparent bg-clip-text bg-gradient-to-r from-blue-500 to-blue-700 drop-shadow-sm">烽火快传</span>
      </div>
      
      {showLoginButton && (
        <Button 
          type="primary" 
          className="bg-gradient-to-r from-blue-500 to-blue-700"
          onClick={() => {
            if(isAdmin){
              navigate('/manage');
            }else{
              navigate('/login');
            }
          }}
        >
          {isAdmin ? '管理后台' : '登录'}
        </Button>
      )}
    </div>
  );
};

export default Header;